@@ -32,8 +32,12 @@ class Environment:
     on_zotac: bool = False;  """Am I on Zotac?"""
     on_think: bool = False;  """Am I on Think?"""
     
-    sp_dir:   str = '';      """Solar-panel directory"""
-    el_dir:   str = '';      """Electricity-meter directory"""
+    sp_dir:          str = '';  """Solar-panel directory"""
+    el_dir:          str = '';  """Electricity-meter directory"""
+    knmi_10min_dir:  str = '';  """Directory for 10-min KNMI data"""
+    knmi_hourly_dir: str = '';  """Directory for hourly KNMI data"""
+    knmi_daily_dir:  str = '';  """Directory for daily KNMI data"""
+    wpw_dir:         str = '';  """WP weather directory"""
     
     
 def environment(cfg_file='.python_environment.cfg'):
@@ -68,6 +72,12 @@ def environment(cfg_file='.python_environment.cfg'):
     # Section ElectricityMeter:
     env.el_dir = config.get('ElectricityMeter', 'basedir', fallback=env.el_dir).replace('~', env.home)  # EM base dir
     
+    # Section Weather:
+    env.knmi_10min_dir  = config.get('Weather', 'knmi_10min_dir',  fallback=env.knmi_10min_dir).replace('~',  env.home)  # KNMI 10-min dir
+    env.knmi_hourly_dir = config.get('Weather', 'knmi_hourly_dir', fallback=env.knmi_hourly_dir).replace('~', env.home)  # KNMI hourly dir
+    env.knmi_daily_dir  = config.get('Weather', 'knmi_daily_dir',  fallback=env.knmi_daily_dir).replace('~', env.home)   # KNMI daily dir
+    env.wpw_dir         = config.get('Weather', 'wpw_dir',         fallback=env.wpw_dir).replace('~', env.home)          # WP weather dir
+    
     return env
 
 
